import{N as c}from"./Navbar-CHbkr9Mo.js";import{e as d,aj as u,b as a,l,a2 as f,f as _,g as b,q as p,k as y,aM as I}from"./jwt-decode.esm-BAacjh9V.js";import"./logo-BiWG9_W5.js";import"./AbstraButton.vue_vue_type_script_setup_true_lang-Ch4HzNzl.js";import"./LoadingOutlined-CcdRxPvd.js";import"./constants-PfoXNq92.js";import"./PhCaretDown.vue-DHWRw9_1.js";import"./PhPencilSimple.vue-CH3QIcJI.js";import"./router-iojlVEw-.js";import"./ts.worker-Bvc4Bt-S.js";import"./organization-DzkN8-kj.js";import"./tables-DT7drM2H.js";import"./string-BGv-YpdF.js";import"./keyboard-qg8EtKo4.js";import"./os-BjRahmWD.js";import"./projectStore-Dd2Dlucx.js";import"./project-Bumi29an.js";import"./organizationSwitcher-BWfqfO2t.js";import"./cascaderStore-BpG8J_8c.js";import"./CreateProjectModal.vue_vue_type_script_setup_true_lang-CUGWlUpl.js";import"./member-QQuRRjke.js";import"./index-CJSmvk-S.js";import"./index-DkibJHUY.js";import"./CreateTableModal.vue_vue_type_script_setup_true_lang-Drs0juGb.js";import"./PhNotePencil.vue-C7mjSKNq.js";import"./PhSignOut.vue-vswURvJq.js";import"./index-BUssfYSM.js";import"./index-B28pIRw2.js";import"./PhPlus.vue-pdTLYlXL.js";import"./omniChatStore-DfiJyJMa.js";import"./files-Dk4Uqd7O.js";import"./contracts.generated-C62MAyib.js";import"./runnerData-C52SbDb4.js";import"./url-D_3vogJH.js";import"./colorHelpers-Dh7fkvz8.js";import"./uuid-C_gSSDsX.js";import"./PhCopySimple.vue-qNZrg3aq.js";import"./PhSparkle.vue-Bw8G4uRQ.js";import"./index-dMlgWP_d.js";(function(){try{var r=typeof window<"u"?window:typeof global<"u"?global:typeof self<"u"?self:{},o=new Error().stack;o&&(r._sentryDebugIds=r._sentryDebugIds||{},r._sentryDebugIds[o]="504a696f-098f-4a90-8b4a-1df60ea4a1b6",r._sentryDebugIdIdentifier="sentry-dbid-504a696f-098f-4a90-8b4a-1df60ea4a1b6")}catch{}})();const g={class:"console-layout"},v={class:"console-content"},w=d({__name:"ConsoleLayout",setup(r){const o=u(),s=a(()=>!!o.params.projectId),n=a(()=>{const t=o.meta.pageNameKey;if(t)return t.startsWith("i18n_")?l.translateIfFound(t,null):t}),m=a(()=>{const t=o.params.projectId,i=o.params.tableId,e=o.params.organizationId;if(t)return{projectId:t,tableId:i,currentPageName:n.value};if(e)return{organizationId:e}});return(t,i)=>{const e=f("RouterView");return b(),_("div",g,[p(c,{"use-cascader":!0,"cascader-props":m.value,"show-ai-sparkles":s.value},null,8,["cascader-props","show-ai-sparkles"]),y("div",v,[p(e)])])}}}),po=I(w,[["__scopeId","data-v-62f8634d"]]);export{po as default};
//# sourceMappingURL=ConsoleLayout-CM6faHvo.js.map
